bbprep.selectors.ByIdSelector
=============================

.. currentmodule:: bbprep.selectors

.. autoclass:: ByIdSelector
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~ByIdSelector.select_atoms
   
   

   
   
   